shithub: sf2mid

Download patch

ref: e763bd93badbd390945a3d0ee25d75e54e4fb8eb
parent: e86d986ed6ccb93b4ee41d2de656c49c721b18db
author: Bernhard Schelling <14200249+schellingb@users.noreply.github.com>
date: Mon Dec 13 18:28:42 EST 2021

Spelling fixes in comments

--- a/tsf.h
+++ b/tsf.h
@@ -98,7 +98,7 @@
 // Free the memory related to this tsf instance
 TSFDEF void tsf_close(tsf* f);
 
 // Stop all playing notes immediatly and reset all channel parameters
 TSFDEF void tsf_reset(tsf* f);
 
 // Returns the preset index from a bank and preset number, or -1 if it does not exist in the loaded SoundFont
@@ -226,7 +226,7 @@
 TSFDEF int tsf_channel_note_on(tsf* f, int channel, int key, float vel);
 TSFDEF void tsf_channel_note_off(tsf* f, int channel, int key);
 TSFDEF void tsf_channel_note_off_all(tsf* f, int channel); //end with sustain and release
-TSFDEF void tsf_channel_sounds_off_all(tsf* f, int channel); //end immediatly
+TSFDEF void tsf_channel_sounds_off_all(tsf* f, int channel); //end immediately
 
 // Apply a MIDI control change to the channel (not all controllers are supported!)
 //    (tsf_channel_midi_control returns 0 on allocation failure of new channel, otherwise 1)
@@ -1054,7 +1054,7 @@
 
 static void tsf_voice_end(tsf* f, struct tsf_voice* v)
 {
-	// if maxVoiceNum is set, assume that voice rendering and note queuing are on sparate threads
+	// if maxVoiceNum is set, assume that voice rendering and note queuing are on separate threads
 	// so to minimize the chance that voice rendering would advance the segment at the same time
 	// we just do it twice here and hope that it sticks
 	int repeats = (f->maxVoiceNum ? 2 : 1);
@@ -1072,7 +1072,7 @@
 
 static void tsf_voice_endquick(tsf* f, struct tsf_voice* v)
 {
-	// if maxVoiceNum is set, assume that voice rendering and note queuing are on sparate threads
+	// if maxVoiceNum is set, assume that voice rendering and note queuing are on separate threads
 	// so to minimize the chance that voice rendering would advance the segment at the same time
 	// we just do it twice here and hope that it sticks
 	int repeats = (f->maxVoiceNum ? 2 : 1);
@@ -98,7 +98,7 @@
 TSFDEF void tsf_close(tsf* f);
 
-// Stop all playing notes immediatly and reset all channel parameters
+// Stop all playing notes immediately and reset all channel parameters
 TSFDEF void tsf_reset(tsf* f);
 